# 1.0.4 (2020-08-31)
* future sprint unresolved issues are shown in backlog

# 1.0.3 (2020-08-30)
* bug fixed to status code being string instead of integer.

# 1.0.2 (2020-08-30)
* Response error handled with message if other than 200.

# 1.0.1 (2020-08-30)
* Installable packaging configuration added.

# 1.0.0 (2020-08-29)
* Birth!